==> db4o-5.0-mono.tar.gz: db4o-5.0/src/test/src/com/db4o/test/SodaNoDuplicates.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using j4o.lang;
using com.db4o;
using com.db4o.query;
namespace com.db4o.test {

   public class SodaNoDuplicates {
      
      public SodaNoDuplicates() : base() {
      }
      internal Atom atom;
      
      public void store() {
         Tester.deleteAllInstances(this);
         Tester.deleteAllInstances(new Atom());
         Atom m11 = new Atom("One");
         Atom m21 = new Atom("Two");
         SodaNoDuplicates snd1 = new SodaNoDuplicates();
         snd1.atom = m11;
         Tester.store(snd1);
         snd1 = new SodaNoDuplicates();
         snd1.atom = m11;
         Tester.store(snd1);
         snd1 = new SodaNoDuplicates();
         snd1.atom = m21;
         Tester.store(snd1);
         snd1 = new SodaNoDuplicates();
         snd1.atom = m21;
         Tester.store(snd1);
      }
      
      public void test() {
         Query q1 = Tester.query();
         q1.constrain(Class.getClassForType(typeof(SodaNoDuplicates)));
         Query qAtoms1 = q1.descend("atom");
         ObjectSet set1 = qAtoms1.execute();
         Tester.ensure(set1.size() == 2);
      }
   }
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/test/src/com/db4o/test/SodaNoDuplicates.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using j4o.lang;
using com.db4o;
using com.db4o.query;
namespace com.db4o.test {

   public class SodaNoDuplicates {
      
      public SodaNoDuplicates() : base() {
      }
      internal Atom atom;
      
      public void Store() {
         Tester.DeleteAllInstances(this);
         Tester.DeleteAllInstances(new Atom());
         Atom m11 = new Atom("One");
         Atom m21 = new Atom("Two");
         SodaNoDuplicates snd1 = new SodaNoDuplicates();
         snd1.atom = m11;
         Tester.Store(snd1);
         snd1 = new SodaNoDuplicates();
         snd1.atom = m11;
         Tester.Store(snd1);
         snd1 = new SodaNoDuplicates();
         snd1.atom = m21;
         Tester.Store(snd1);
         snd1 = new SodaNoDuplicates();
         snd1.atom = m21;
         Tester.Store(snd1);
      }
      
      public void Test() {
         Query q1 = Tester.Query();
         q1.Constrain(Class.GetClassForType(typeof(SodaNoDuplicates)));
         Query qAtoms1 = q1.Descend("atom");
         ObjectSet set1 = qAtoms1.Execute();
         Tester.Ensure(set1.Size() == 2);
      }
   }
}
